Module: Assertions

Defined in:
lib/gmail_test/assertions/gmail.rb,
lib/gmail_test/assertions/base.rb

Overview

These assertions are compatible with gmail with english language set in settings. They do tests using html basic view for gmail.

Defined Under Namespace

Modules: Base, Gmail